@@ -154,7 +154,7 @@ if ($ret === FALSE) {
 if (isset($_POST["update"])) {
     if (mod_passwd($_POST) === FALSE) {
         result_log(OPERATION . ":NG:" . $err_msg);
-        $err_msg = htmlspecialchars($err_msg);
+        $err_msg = escape_html($err_msg);
     } else {
         result_log(OPERATION . ":OK:" . $err_msg);
 
