@@ -110,7 +110,7 @@ function set_tag_data($post, &$tag)
 
         /* ᡼륨ꥢʬ */
         if (isset($ldapdata[0]['mailAlias'][0])) {
-            $ldapalias = htmlspecialchars($ldapdata[0]['mailAlias'][0]);
+            $ldapalias = escape_html($ldapdata[0]['mailAlias'][0]);
             $part = explode("@", $ldapalias, 2);
             $postdata['alias'] = $part[0];
         }
